@@ -105,7 +105,7 @@ def _get_one_batch_after_timestamp(data_source, latest_timestamp):
 
     metadata = _get_metadata_from_dynamodb(data_source, latest_timestamp)
     if metadata is None:
-        return None, None
+        return None, None, None, None
 
     batch = s3.Object(metadata["bucket_name"], metadata["file_name"]).get()['Body'].read()
     return batch, metadata["timestamp"], metadata['file_name'], metadata
