@@ -31,7 +31,7 @@ def _upload_data_to_s3(object_in, filename):
     return response
 
 
-def upload_to_datalake(object_in, consumer_services, data_type, source_company, file_name):
+def upload_to_datalake(object_in, data_type, source_company, file_name):
     # upload object to S3
     now = datetime.now()
     date = now.date()
